@@ -298,7 +298,7 @@ resolve_start (YelpUri *uri)
     if (priv->resolver == NULL) {
         g_object_ref (uri);
         priv->resolver = g_thread_new ("uri-resolve",
-                                       (GThreadFunc) resolve_async,
+                                       (GThreadFunc)(GCallback) resolve_async,
                                        uri);
     }
 }
